================
Console Programs
================

The primary application of this library is to provide these console scripts
to the user to easily execute HiRISE processing procedures.

.. autoprogram:: hiproc.hiproc:arg_parser()
   :prog: hiproc

.. autoprogram:: hiproc.bitflips:arg_parser()
   :prog: bitflips

.. autoprogram:: hiproc.EDR_Stats:arg_parser()
   :prog: EDR_Stats

.. autoprogram:: hiproc.HiBeautify:arg_parser()
   :prog: HiBeautify

.. autoprogram:: hiproc.HiCal:arg_parser()
   :prog: HiCal

.. autoprogram:: hiproc.HiccdStitch:arg_parser()
   :prog: HiccdStitch

.. autoprogram:: hiproc.HiColorInit:arg_parser()
   :prog: HiColorInit

.. autoprogram:: hiproc.HiColorNorm:arg_parser()
   :prog: HiColorNorm

.. autoprogram:: hiproc.HiJACK:arg_parser()
   :prog: HiJACK

.. autoprogram:: hiproc.HiJitReg:arg_parser()
   :prog: HiJitReg

.. autoprogram:: hiproc.HiNoProj:arg_parser()
   :prog: HiNoProj

.. autoprogram:: hiproc.HiPrecisionInit:arg_parser()
   :prog: HiPrecisionInit

.. autoprogram:: hiproc.HiSlither:arg_parser()
   :prog: HiSlither

.. autoprogram:: hiproc.HiStitch:arg_parser()
   :prog: HiStitch

.. autoprogram:: hiproc.JitPlot:arg_parser()
   :prog: JitPlot

.. autoprogram:: hiproc.lisfix:arg_parser()
   :prog: lisfix

.. autoprogram:: hiproc.SlitherStats:arg_parser()
   :prog: SlitherStats

.. autoprogram:: hiproc.resolve_jitter:arg_parser()
   :prog: resolve_jitter
